==> imp-1.0.tar.gz: imp-1.0/modules/algebra/include/internal/tnt_array1d_utils.h <==
/*
*
* Template Numerical Toolkit (TNT)
*
* Mathematical and Computational Sciences Division
* National Institute of Technology,
* Gaithersburg, MD USA
*
*
* This software was developed at the National Institute of Standards and
* Technology (NIST) by employees of the Federal Government in the course
* of their official duties. Pursuant to title 17 Section 105 of the
* United States Code, this software is not subject to copyright protection
* and is in the public domain. NIST assumes no responsibility whatsoever for
* its use by other parties, and makes no guarantees, expressed or implied,
* about its quality, reliability, or any other characteristic.
*
*/

#ifndef IMPALGEBRA_TNT_ARRAY_1D_UTILS_H
#define IMPALGEBRA_TNT_ARRAY_1D_UTILS_H

#include "../algebra_config.h"
#include <cstdlib>
#include <cassert>

IMPALGEBRA_BEGIN_INTERNAL_NAMESPACE
namespace TNT
{
using namespace std;


template <class T>
std::ostream& operator<<(std::ostream &s, const Array1D<T> &A)
{
    int N=A.dim1();

#ifdef TNT_DEBUG
  s << "addr: " << (void *) &A[0] << "\n";
#endif
    s << N << "\n";
    for (int j=0; j<N; j++)
    {
       s << A[j] << "\n";
    }
    s << "\n";

    return s;
}

template <class T>
std::istream& operator>>(std::istream &s, Array1D<T> &A)
{
  int N;
  s >> N;

  Array1D<T> B(N);
  for (int i=0; i<N; i++)
    s >> B[i];
  A = B;
  return s;
}



template <class T>
Array1D<T> operator+(const Array1D<T> &A, const Array1D<T> &B)
{
  int n = A.dim1();

  if (B.dim1() != n )
    return Array1D<T>();

  else
  {
    Array1D<T> C(n);

    for (int i=0; i<n; i++)
    {
      C[i] = A[i] + B[i];
    }
    return C;
  }
}



template <class T>
Array1D<T> operator-(const Array1D<T> &A, const Array1D<T> &B)
{
  int n = A.dim1();

  if (B.dim1() != n )
    return Array1D<T>();

  else
  {
    Array1D<T> C(n);

    for (int i=0; i<n; i++)
    {
      C[i] = A[i] - B[i];
    }
    return C;
  }
}


template <class T>
Array1D<T> operator*(const Array1D<T> &A, const Array1D<T> &B)
{
  int n = A.dim1();

  if (B.dim1() != n )
    return Array1D<T>();

  else
  {
    Array1D<T> C(n);

    for (int i=0; i<n; i++)
    {
      C[i] = A[i] * B[i];
    }
    return C;
  }
}


template <class T>
Array1D<T> operator/(const Array1D<T> &A, const Array1D<T> &B)
{
  int n = A.dim1();

  if (B.dim1() != n )
    return Array1D<T>();

  else
  {
    Array1D<T> C(n);

    for (int i=0; i<n; i++)
    {
      C[i] = A[i] / B[i];
    }
    return C;
  }
}









template <class T>
Array1D<T>&  operator+=(Array1D<T> &A, const Array1D<T> &B)
{
  int n = A.dim1();

  if (B.dim1() == n)
  {
    for (int i=0; i<n; i++)
    {
        A[i] += B[i];
    }
  }
  return A;
}




template <class T>
Array1D<T>&  operator-=(Array1D<T> &A, const Array1D<T> &B)
{
  int n = A.dim1();

  if (B.dim1() == n)
  {
    for (int i=0; i<n; i++)
    {
        A[i] -= B[i];
    }
  }
  return A;
}



template <class T>
Array1D<T>&  operator*=(Array1D<T> &A, const Array1D<T> &B)
{
  int n = A.dim1();

  if (B.dim1() == n)
  {
    for (int i=0; i<n; i++)
    {
        A[i] *= B[i];
    }
  }
  return A;
}




template <class T>
Array1D<T>&  operator/=(Array1D<T> &A, const Array1D<T> &B)
{
  int n = A.dim1();

  if (B.dim1() == n)
  {
    for (int i=0; i<n; i++)
    {
        A[i] /= B[i];
    }
  }
  return A;
}






} // namespace TNT

IMPALGEBRA_END_INTERNAL_NAMESPACE

#endif /* IMPALGEBRA_TNT_ARRAY_1D_UTILS_H */

==> imp-2.0.0.tar.gz: imp-2.0.0/modules/algebra/include/internal/tnt_array1d_utils.h <==
/*
*
* Template Numerical Toolkit (TNT)
*
* Mathematical and Computational Sciences Division
* National Institute of Technology,
* Gaithersburg, MD USA
*
*
* This software was developed at the National Institute of Standards and
* Technology (NIST) by employees of the Federal Government in the course
* of their official duties. Pursuant to title 17 Section 105 of the
* United States Code, this software is not subject to copyright protection
* and is in the public domain. NIST assumes no responsibility whatsoever for
* its use by other parties, and makes no guarantees, expressed or implied,
* about its quality, reliability, or any other characteristic.
*
*/

#ifndef IMPALGEBRA_TNT_ARRAY_1D_UTILS_H
#define IMPALGEBRA_TNT_ARRAY_1D_UTILS_H

#include <IMP/algebra/algebra_config.h>
#include <cstdlib>
#include <cassert>

IMPALGEBRA_BEGIN_INTERNAL_NAMESPACE
namespace TNT
{
using namespace std;


template <class T>
inline std::ostream& operator<<(std::ostream &s, const Array1D<T> &A)
{
    int N=A.dim1();

#ifdef TNT_DEBUG
  s << "addr: " << (void *) &A[0] << "\n";
#endif
    s << N << "\n";
    for (int j=0; j<N; j++)
    {
       s << A[j] << "\n";
    }
    s << "\n";

    return s;
}

template <class T>
inline std::istream& operator>>(std::istream &s, Array1D<T> &A)
{
  int N;
  s >> N;

  Array1D<T> B(N);
  for (int i=0; i<N; i++)
    s >> B[i];
  A = B;
  return s;
}



template <class T>
inline Array1D<T> operator+(const Array1D<T> &A, const Array1D<T> &B)
{
  int n = A.dim1();

  if (B.dim1() != n )
    return Array1D<T>();

  else
  {
    Array1D<T> C(n);

    for (int i=0; i<n; i++)
    {
      C[i] = A[i] + B[i];
    }
    return C;
  }
}



template <class T>
inline Array1D<T> operator-(const Array1D<T> &A, const Array1D<T> &B)
{
  int n = A.dim1();

  if (B.dim1() != n )
    return Array1D<T>();

  else
  {
    Array1D<T> C(n);

    for (int i=0; i<n; i++)
    {
      C[i] = A[i] - B[i];
    }
    return C;
  }
}


template <class T>
inline Array1D<T> operator*(const Array1D<T> &A, const Array1D<T> &B)
{
  int n = A.dim1();

  if (B.dim1() != n )
    return Array1D<T>();

  else
  {
    Array1D<T> C(n);

    for (int i=0; i<n; i++)
    {
      C[i] = A[i] * B[i];
    }
    return C;
  }
}


template <class T>
inline Array1D<T> operator/(const Array1D<T> &A, const Array1D<T> &B)
{
  int n = A.dim1();

  if (B.dim1() != n )
    return Array1D<T>();

  else
  {
    Array1D<T> C(n);

    for (int i=0; i<n; i++)
    {
      C[i] = A[i] / B[i];
    }
    return C;
  }
}









template <class T>
inline Array1D<T>&  operator+=(Array1D<T> &A, const Array1D<T> &B)
{
  int n = A.dim1();

  if (B.dim1() == n)
  {
    for (int i=0; i<n; i++)
    {
        A[i] += B[i];
    }
  }
  return A;
}




template <class T>
inline Array1D<T>&  operator-=(Array1D<T> &A, const Array1D<T> &B)
{
  int n = A.dim1();

  if (B.dim1() == n)
  {
    for (int i=0; i<n; i++)
    {
        A[i] -= B[i];
    }
  }
  return A;
}



template <class T>
inline Array1D<T>&  operator*=(Array1D<T> &A, const Array1D<T> &B)
{
  int n = A.dim1();

  if (B.dim1() == n)
  {
    for (int i=0; i<n; i++)
    {
        A[i] *= B[i];
    }
  }
  return A;
}




template <class T>
inline Array1D<T>&  operator/=(Array1D<T> &A, const Array1D<T> &B)
{
  int n = A.dim1();

  if (B.dim1() == n)
  {
    for (int i=0; i<n; i++)
    {
        A[i] /= B[i];
    }
  }
  return A;
}






} // namespace TNT

IMPALGEBRA_END_INTERNAL_NAMESPACE

#endif /* IMPALGEBRA_TNT_ARRAY_1D_UTILS_H */
